summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-20 22:49:47 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-20 22:49:47 +0000
commit51bd36619bfaa05e98b3a6f58d48aaca6a66e307 (patch)
tree93b978a5ac16359aee752c8d41413e24410fc51d /chrome/common
parent655aa8d8075c12a8846bedfb080ab71f4231aaa0 (diff)
downloadchromium_src-51bd36619bfaa05e98b3a6f58d48aaca6a66e307.zip
chromium_src-51bd36619bfaa05e98b3a6f58d48aaca6a66e307.tar.gz
chromium_src-51bd36619bfaa05e98b3a6f58d48aaca6a66e307.tar.bz2
Rename AutoFillForm to FormFieldValues to better reflect the purpose of the data structure.
BUG=none TEST=none Review URL: http://codereview.chromium.org/306014 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@29580 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/render_messages.h16
-rw-r--r--chrome/common/render_messages_internal.h4
2 files changed, 9 insertions, 11 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 908c7a4..a4dbf29 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -1258,8 +1258,8 @@ IPC_BEGIN_MESSAGES(ViewHost)
std::vector<webkit_glue::PasswordForm> /* forms */)
// Notification that a form has been submitted. The user hit the button.
- IPC_MESSAGE_ROUTED1(ViewHostMsg_AutofillFormSubmitted,
- webkit_glue::AutofillForm /* form */)
+ IPC_MESSAGE_ROUTED1(ViewHostMsg_FormFieldValuesSubmitted,
+ webkit_glue::FormFieldValues /* form */)
// Used to tell the parent the user started dragging in the content area. The
// WebDropData struct contains contextual information about the pieces of the
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h
index d4925a0..ccaa4e0 100644
--- a/chrome/common/render_messages.h
+++ b/chrome/common/render_messages.h
@@ -34,9 +34,9 @@
#include "net/base/upload_data.h"
#include "net/http/http_response_headers.h"
#include "webkit/appcache/appcache_interfaces.h"
-#include "webkit/glue/autofill_form.h"
#include "webkit/glue/context_menu.h"
#include "webkit/glue/form_data.h"
+#include "webkit/glue/form_field_values.h"
#include "webkit/glue/password_form.h"
#include "webkit/glue/password_form_dom_manager.h"
#include "webkit/glue/resource_loader_bridge.h"
@@ -733,16 +733,14 @@ struct ParamTraits<webkit_glue::PasswordForm> {
}
};
// Traits for AutofillForm_Params structure to pack/unpack.
template <>
-struct ParamTraits<webkit_glue::AutofillForm> {
- typedef webkit_glue::AutofillForm param_type;
+struct ParamTraits<webkit_glue::FormFieldValues> {
+ typedef webkit_glue::FormFieldValues param_type;
static void Write(Message* m, const param_type& p) {
WriteParam(m, p.elements.size());
- for (std::vector<webkit_glue::AutofillForm::Element>::const_iterator itr =
- p.elements.begin();
- itr != p.elements.end();
- itr++) {
+ std::vector<webkit_glue::FormFieldValues::Element>::const_iterator itr;
+ for (itr = p.elements.begin(); itr != p.elements.end(); itr++) {
WriteParam(m, itr->name);
WriteParam(m, itr->value);
}
@@ -759,7 +757,7 @@ struct ParamTraits<webkit_glue::AutofillForm> {
return result;
}
static void Log(const param_type& p, std::wstring* l) {
- l->append(L"<AutofillForm>");
+ l->append(L"<FormFieldValues>");
}
};
@@ -733,16 +733,14 @@ struct ParamTraits<webkit_glue::PasswordForm> {
}
};
-// Traits for AutofillForm_Params structure to pack/unpack.
+// Traits for FormFieldValues_Params structure to pack/unpack.
template <>